Configuration Manager — BCI-Framework documentation

# Configuration Manager

class `bci_framework.framework.config_manager.` `ConfigManager`(filename='.bciframework')

  File based configurations manager.

  `connect_widgets`(method: Callable, config: Dict[str, QWidget]) → None

    Automatically connect widgets with events.

  `get`(section: str, option: str, default: Optional[str] = None, *args, **kwargs) → None

    Read a configuration value, if not exists then save the default.

  `load`() → None

    Load the filename with configirations.

  `load_widgets`(section: str, config: Dict[str, QWidget]) → None

    Automatically load values from configurations and set them in widgets.

  `save`() → None

    Save configurations.

  `save_widgets`(section: str, config: Dict[str, QWidget]) → None

    Automatically save values from widgets.

  `set`(section: str, option: str, value: Optional[str] = '', save: Optional[bool] = False) → None

    Write and save configuration option.